Changelog
=========

`2.0.0`_
--------

- removed ``/sticker`` command.
- allow to search for sticker packs.
- allow to get a random sticker for an emoji.
- delete zipped pack after it is sent.
- cache stickers and packs metadata.
- limit the size of the zipped pack.

1.0.0
-----

- initial release


.. _Unreleased: https://github.com/adbenitez/simplebot_stickers/compare/v2.0.0...HEAD
.. _Unreleased: https://github.com/adbenitez/simplebot_stickers/compare/v1.0.0...v2.0.0
